Gauge Python
============

|Travis Build Status| |Codacy Project Status| |Documentation Status| |MIT licensed|

Python language runner for `Gauge`_.

* `Documentation`_
* `Contributing`_

Examples
--------

* `Selenium`_
* `Selenium and REST API`_

Issues
------

If you find any issues or have any feature requests, please file them in the `issue tracker`_.

.. _issue tracker: https://github.com/kashishm/gauge-python/issues

License
-------

The Gauge-Python is an open-sourced software licensed under the `MIT license`_.

.. _Gauge: https://github.com/getgauge/gauge
.. _Documentation: https://gauge-python.readthedocs.org
.. _Contributing: https://gauge-python.readthedocs.io/en/latest/contributing.html
.. _MIT license: http://opensource.org/licenses/MIT
.. _Selenium: https://github.com/kashishm/gauge-example-python
.. _Selenium and REST API: https://angbaird.com/2016/11/09/selenium-and-rest-api-testing-with-gauge/

.. |Documentation Status| image:: https://readthedocs.org/projects/gauge-python/badge/?version=latest
   :target: http://gauge-python.readthedocs.org/en/latest/?badge=latest
.. |Travis Build Status| image:: https://travis-ci.org/kashishm/gauge-python.svg?branch=master
   :target: https://travis-ci.org/kashishm/gauge-python
.. |Codacy Project Status| image:: https://api.codacy.com/project/badge/Grade/2b96566538d1445685f9ad7792456b97
   :target: https://www.codacy.com/app/kashishmunjal64/gauge-python?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=kashishm/gauge-python&amp;utm_campaign=Badge_Grade
.. |MIT licensed| image:: https://img.shields.io/badge/license-MIT-blue.svg
   :target: https://github.com/kashishm/gauge-python/blob/master/LICENSE.txt